
# Open Weather Map API Python Package

Package that take current and forecast weather in select location.

Location options:
* By City
* By Geographic Location Coordinates.

## Install intructions

### Windows
```pip install <package>```

### Linux / MacOSx
```pip3 install <package>```